@@ -49,9 +49,9 @@ namespace _orbitcpp {
         }
     };
 
-    template <class CPPType, class CElem, class CElemSeq, CORBA_TypeCode seq_typecode>
-    struct type_seq_traits : public simple_seq_traits<typename CPPType::value_t, CElem, CElemSeq, seq_typecode> {
-	typedef typename CPPType::value_t value_t;
+    template <class CPPType, class CPPElem, class CElem, class CElemSeq, CORBA_TypeCode seq_typecode>
+    struct type_seq_traits : public simple_seq_traits<CPPElem, CElem, CElemSeq, seq_typecode> {
+	typedef CPPElem value_t;
 	typedef CElem c_value_t;
 
 	static void pack_elem (const value_t &cpp_elem, c_value_t &c_elem)
@@ -188,7 +188,7 @@ namespace _orbitcpp {
     {
 	typedef SeqTraits traits_t;
 	typedef typename traits_t::value_t  value_t;
-	typedef typename traits_t::c_elem_t c_value_t;
+	typedef typename traits_t::c_value_t c_value_t;
 	typedef typename traits_t::c_seq_t  c_seq_t;
 	
 	typedef CompoundSeqBase<value_t, SeqTraits> Super;
